#!/usr/bin/env zsh
# Simple test which decodes some images from LBX archives and compares against
# known md5sums to find regressions.  Unforuntately depends on the output
# format of lbximg; this may change in the future.

# Image/tool paths.  Adjust to taste.  The DATADIR must contain the original
# Moo2 LBX archives, with filenames in lower case.
DATADIR=$HOME/.2oom/game
LBXTOOL=`readlink -f ../lbxtool`
LBXIMG=`readlink -f ../lbximg`

# Status vars
FAILED=0

if ! SCRATCH=`mktemp -d`; then
	exit 1
fi

cd $SCRATCH || exit 1
echo "Working in $SCRATCH"

# Palettes
$LBXTOOL -xf $DATADIR/fonts.lbx

compare()
{
	echo -n "  Frame $1 "

	FILE=`printf 'out.%03d.png' $1`
	MD5=`md5sum $FILE | cut -d ' ' -f 1`

	if [[ $MD5 == $2 ]]; then
		echo OK
		rm -f $FILE
	else
		echo FAILED
		FAILED=`expr $FAILED + 1`
	fi
}

# Main menu
$LBXTOOL -xf $DATADIR/mainmenu.lbx mainmenu.lbx.{000,007,021}

echo "mainmenu.lbx.021: single frame, embedded palette:"
$LBXIMG -df mainmenu.lbx.021
compare 0 b5d488667bed557a089c5d8f8b0a3d64

echo "mainmenu.lbx.007: single frame, external palette:"
$LBXIMG -dp fonts.lbx.006 < mainmenu.lbx.007
compare 0 5b9a1a10e4979531e91a41f02ee40537

echo "mainmenu.lbx.000: multi frame, external palette:"
$LBXIMG -dp fonts.lbx.006 < mainmenu.lbx.000 0 15 49
compare  0 6556baafebe441498f33865f2e9eb0de
compare 15 76a6e8fe18614423f8780ee80f513e8c
compare 49 b5d488667bed557a089c5d8f8b0a3d64

# Logos
$LBXTOOL -xf $DATADIR/logo.lbx

echo "logo.lbx.000: single frame, embedded palette, transparency:"
$LBXIMG -df logo.lbx.000
compare 0 cf4cbcb834ef35890d1283928b0187bf

echo "logo.lbx.001: multi frame, embedded palette:"
$LBXIMG -df logo.lbx.001 0 30 63
compare  0 542778cde51dc821e225ddd4a16dc197
compare 30 609c2b9be5a1e18f5c36398554f9f2ec
compare 63 664b12c7259948900ded3ff93e1f4ec7

# Ships
$LBXTOOL -xf $DATADIR/ships.lbx ships.lbx.{042,049}

echo "ships.lbx.042: single frame, external+override palette, transparency:"
$LBXIMG -df ships.lbx.042 -p fonts.lbx.012 -O ships.lbx.049
compare 0 3426ef9c5c8e3dfbd1a95ed9211e2342

# Nebulae
$LBXTOOL -xf $DATADIR/starbg.lbx starbg.lbx.009

echo "starbg.lbx.009: single frame, raw data:"
$LBXIMG -df starbg.lbx.009 -p fonts.lbx.005
compare 0 2e430234f410ef208f78d99a64fa449f

# Monsters
$LBXTOOL -xf $DATADIR/monster.lbx monster.lbx.{007,014}

echo "monster.lbx.007: multi frame, chunked:"
$LBXIMG -df monster.lbx.007 -p fonts.lbx.004 -O monster.lbx.014 0 5 19
compare  0 20eb7d52abb3cd718426d4732d9e2286
compare  5 ea8c7a5fbeb9043fd8f30ae91b13550a
compare 19 d501ecf1599ea724846625a9711c6ccb

# Clean up
if [[ $FAILED -eq 0 ]]; then
	echo "All tests completed successfully."
	rm -rf -- $SCRATCH
else
	echo "$FAILED test(s) FAILED"
	exit 1
fi
